@@ -1,7 +1,7 @@
 #! /usr/bin/perl
 
 # ex:ts=8 sw=4:
-# $OpenBSD: Quirks.pm,v 1.535 2017/09/22 06:39:40 tb Exp $
+# $OpenBSD: Quirks.pm,v 1.582 2018/03/16 22:06:26 fcambus Exp $
 #
 # Copyright (c) 2009 Marc Espie <espie@openbsd.org>
 #
@@ -490,9 +490,21 @@ my $stem_extensions = {
 	'zarafa-mapi' => 'kopano-mapi',
 	'zarafa-webapp' => 'kopano-webapp',
 	'extract_url' => 'extracturl',
+# 6.3
+	'ruby-arirang' => 'arirang',
+	'ja-mplus-ttf' => 'mixfont-mplus-ipa',
+	'kdirstat' => 'qdirstat',
+	'stem' => 'py-stem',
+	'arm' => 'nyx',
+	'luabitop' => 'lua-bitop',
+	'livestreamer' => 'streamlink',
+	'newsbeuter' => 'newsboat',
+	'php-fastcgi' => 'php-cgi',
+	'advancemess' => 'advancemame',
 };
 
 my $obsolete_reason = {
+# 5.5
 	'BitTorrent' => 0,
 	'BitTorrent-gui' => 0,
 	'sgmlformat' => 0,
@@ -510,6 +522,7 @@ my $obsolete_reason = {
 	'apc-upsd' => 3,
 	'mod_bandwidth' => 3,
 	'varconf' => 0,
+# 5.6
 	'radiusd-cistron' => 2,
 	'radiusd-lucent' => 2,
 	'emesene' => 0,
@@ -549,6 +562,7 @@ my $obsolete_reason = {
 	'xmms-bonk' => 3,
 	'mailcrypt' => 0,
 	'tcpcat' => 4,
+# 5.7
 	'ctm' => 3,
 	'papyon' => 3,
 	'bacula-web' => 1,
@@ -617,6 +631,7 @@ my $obsolete_reason = {
 	'hs-stringtable-atom' => 5,
 	'pugs' => 5,
 	'xawtv' => 5,
+# 5.8
 	'qt4-eventsview' => 0,
 	'rioutil' => 3,
 	'chmsee' => 0,
@@ -697,6 +712,7 @@ my $obsolete_reason = {
 	'tla' => 3,
 	'googlecl' => 3,
 	'cyphertite' => 3,
+# 5.9
 	'cxxtools' => 5,
 	'tntnet' => 6,
 	'dwb' => 6,
@@ -823,6 +839,7 @@ my $obsolete_reason = {
 	'hs-simple-sendfile' => 5,
 	'monadius' => 3,
 	'hs-bimap' => 5,
+# 6.0
 	'nicotine' => 3,
 	'toprump' => 3,
 	'fedora_base' => 0,
@@ -832,7 +849,7 @@ my $obsolete_reason = {
 	'xcept' => 0,
 	'cqcam' => 6,
 	'uisp' => 6,
-        'libretto-config' => 6,
+	'libretto-config' => 6,
 	'courtney' => 2,
 	'junkbuster' => 2,
 	'icb' => 0,
@@ -892,6 +909,7 @@ my $obsolete_reason = {
 	'yt' => 0,
 	'gmime-sharp' => 6,
 	'py-subvertpy' => 5,
+# 6.1
 	'clamz' => 3,
 	'p5-Net-Abuse-Utils-Spamhaus' => 6,
 	'mlite' => 3,
@@ -1027,6 +1045,7 @@ my $obsolete_reason = {
 	'pigment' => 3,
 	'py-pigment' => 3,
 	'gogo' => 3,
+# 6.2
 	'spectemu' => 3,
 	'pinpoint' => 3,
 	'anjuta' => 3,
@@ -1122,6 +1141,104 @@ my $obsolete_reason = {
 	'toad' => 3,
 	'pgp' => 3,
 	'gonzui' => 3,
+# 6.3
+	'puppet-dashboard' => 5,
+	'dnsfilter' => 3,
+	'empathy' => 6,
+	'telepathy-salut' => 3,
+	'telepthy-haze' => 3,
+	'telepathy-idle' => 3,
+	'telepathy-gabble' => 3,
+	'telepathy-qt' => 3,
+	'telepathy-farstream' => 3,
+	'farstream' => 3,
+	'libnice' => 6,
+	'ardour' => 5,
+	'aubio' => 5,
+	'liblo' => 5,
+	'libgnomecanvasmm' => 5,
+	'mixmaster' => 2,
+	'xscorch' => 0,
+	'libwbxml' => 5,
+	'haskell-platform' => 6,
+	'gnokii' => 0,
+	'dee' => 5,
+	'pidgin-tlen' => 6,
+	'pep8' => 5,
+	'hs-aeson' => 6,
+	'hs-GLURaw' => 6,
+	'hs-GLUT' => 6,
+	'hs-OpenGL' => 6,
+	'hs-OpenGLRaw' => 6,
+	'gnuvd' => 6,
+	'gtkhtml4' => 5,
+	'livestreamer-curses' => 6,
+	'xdmchoose' => 6,
+	'hs-BoundedChan' => 6,
+	'hs-HDBC-mysql' => 6,
+	'hs-HDBC-postgresql' => 6,
+	'hs-MonadRandom' => 6,
+	'hs-ObjectName' => 6,
+	'hs-PSQueue' => 6,
+	'hs-StateVar' => 6,
+	'hs-abstract-deque' => 6,
+	'hs-abstract-par' => 6,
+	'hs-base-unicode-symbols' => 6,
+	'hs-blaze-textual' => 6,
+	'hs-bytestring-mmap' => 6,
+	'hs-bytestring-nums' => 6,
+	'hs-case-insensitive' => 6,
+	'hs-cgi' => 6,
+	'hs-cmdlib' => 6,
+	'hs-concurrent-extra' => 6,
+	'hs-crypto' => 6,
+	'hs-cryptocipher' => 6,
+	'hs-curl' => 6,
+	'hs-data-hash' => 6,
+	'hs-directory-tree' => 6,
+	'hs-enumerator' => 6,
+	'hs-failure' => 6,
+	'hs-ghc-paths' => 6,
+	'hs-half' => 6,
+	'hs-hashtables' => 6,
+	'hs-haskell-src' => 6,
+	'hs-hedis' => 6,
+	'hs-hexpat' => 6,
+	'hs-hood' => 6,
+	'hs-largeword' => 6,
+	'hs-logict' => 6,
+	'hs-murmur-hash' => 6,
+	'hs-mwc-random' => 6,
+	'hs-network-info' => 6,
+	'hs-newtype' => 6,
+	'hs-parallel' => 6,
+	'hs-patch-combinators' => 6,
+	'hs-postgresql-libpq' => 6,
+	'hs-pwstore-fast' => 6,
+	'hs-readline' => 6,
+	'hs-sendfile' => 6,
+	'hs-skein' => 6,
+	'hs-strict' => 6,
+	'hs-tuple' => 6,
+	'hs-zlib-bindings' => 6,
+	'vomit' => 0,
+	'p5-WWW-YouTube-Download' => 6,
+	'oggtag' => 6,
+	'tacacs+' => 0,
+	'aimsniff' => 6,
+	'pork' => 6,
+	'ntimed' => 3,
+	'hs-dataenc' => 3,
+	'man2web' => 2,
+	'decss' => 6,
+	'libgcal' => 6,
+	'akonadi-googledata' => 6,
+	'arora' => 3,
+	'powerdns-ldap' => 6,
+	'p5-Net-LDNS' => 6,
+	'sirc' => 0,
+	'hgview' => 6,
+	'xerces' => 5,
 };
 
 # reasons for obsolete packages
@@ -1180,7 +1297,7 @@ sub filter_obsolete
 	for my $pkgname (@in) {
 		my $stem = OpenBSD::PackageName::splitstem($pkgname);
 		my $reason = $obsolete_reason->{$stem};
-		$reason = 3 if (!defined $reason && $pkgname =~ m/^drupal(-6|6-)/);
+		$reason = 3 if (!defined $reason && $pkgname =~ m/^(drupal(-6|6-)|ruby(19|2[0-2])-|ruby-[^0-9])/);
 		if (defined $reason) {
 			$state->say("Obsolete package: #1 (#2)", $pkgname, 
 			    $msg[$reason]);
